@@ -3,7 +3,7 @@
 	some SSQLS types to build SELECT queries with custom WHERE clauses.
 
  Copyright (c) 1998 by Kevin Atkinson, (c) 1999-2001 by MySQL AB, (c)
- 2004-2008 by Educational Technology Resources, Inc., and (c) 2005 by
+ 2004-2009 by Educational Technology Resources, Inc., and (c) 2005 by
  Chris Frey.  Others may also hold copyrights on code in this file.
  See the CREDITS.txt file in the top directory of the distribution
  for details.
@@ -39,14 +39,15 @@ int
 main(int argc, char *argv[])
 {
 	// Get database access parameters from command line
-	const char* db = 0, *server = 0, *user = 0, *pass = "";
-	if (!parse_command_line(argc, argv, &db, &server, &user, &pass)) {
+	mysqlpp::examples::CommandLine cmdline(argc, argv);
+	if (!cmdline) {
 		return 1;
 	}
 
 	try {
 		// Establish the connection to the database server.
-		mysqlpp::Connection con(db, server, user, pass);
+		mysqlpp::Connection con(mysqlpp::examples::db_name,
+				cmdline.server(), cmdline.user(), cmdline.pass());
 
 		// Get all the rows in the stock table.
 		mysqlpp::Query query = con.query("select * from stock");
